@@ -2,9 +2,7 @@
 #Shit to appease Maemo's stupid-ass Policy system added by Faheem Pervez
 
 from ctypes import *
-
-import sys, os, time, thread
-import glib, gobject
+import gobject
 
 pulse_lib = CDLL("libpulse-mainloop-glib.so.0")
 gobject_lib = CDLL("libgobject-2.0.so.0")
