@@ -336,7 +336,10 @@ class Panda(QtGui.QMainWindow): #main class
 					fmtx_iface.Set("com.nokia.FMTx.Device", "state", dbus.String(u'%s' % 'disabled', variant_level=1))
 				else:
 					self.ui.actionEnable_FM_Radio.setText(QtGui.QApplication.translate("pyRadio", "Disable FM Tx", None, QtGui.QApplication.UnicodeUTF8))
-		except: print "No FM Transmitter."
+		except: 
+			self.ui.actionEnable_FM_Radio.setText(QtGui.QApplication.translate("pyRadio", "Set Max Volume", None, QtGui.QApplication.UnicodeUTF8))
+			if not initial:
+				self.player.setVolume( 100 ) 
 
 #Orientation Control
 
