@@ -57,6 +57,9 @@ class RadioPlayer(QtCore.QThread): #Main radio class
 			print "Playing"
 		self.emit(QtCore.SIGNAL("state_change"))
 
+	def setVolume( self, volume ):
+		self.player.set_volume( volume )
+		
 	def createStation( self, stationId ): #Create a station at Pandora
 		ret = self.pandora.createStation( stationId )
 		return ret["stationId"]
